# DABEST (Python)
<!-- [![Build Status](https://travis-ci.org/ACCLAB/DABEST-python.svg?branch=master)](https://travis-ci.org/ACCLAB/DABEST-python)

![](https://raw.githubusercontent.com/ACCLAB/DABEST-python/master/images/readme-float-contrast.png) -->

## About

DABEST is a package for **D**ata **A**nalysis using **B**ootstrapped **EST**imation.

![Gardner-Altman plot](https://acclab.github.io/DABEST-python-docs/_images/f1.png)

The current version is __0.1.0__.

## Requirements

Python 3.6 is strongly recommended, although this has been tested with Python 2.7 and Python 3.5.

In addition, the following packages are also required:
- [numpy](https://www.numpy.org/) (1.13.1)
- [scipy](https://www.scipy.org/) (1.0.0)
- [matplotlib](https://www.matplotlib.org/) (2.0.2)
- [seaborn](https://seaborn.pydata.org/) (0.8)
- [pandas](https://pandas.pydata.org/) (0.21.0).

To obtain these package dependencies easily, it is highly recommended to download the [Anaconda distribution](https://www.continuum.io/downloads) of Python.

## Installation

You can install this package via `pip`.

To install, at the command line run
<!-- ```shell
conda config --add channels conda-forge
conda install dabest
```
or -->
```shell
pip install --upgrade dabest
```
You can also clone this repo locally (see intstructions [here](https://help.github.com/articles/cloning-a-repository/)).

Then, navigate to the cloned repo in the command line and run

```shell
pip install .
```

## Usage

Please refer to the [documentation](https://acclab.github.io/DABEST-python-docs/index.html).

## Matlab version

There is also a [Matlab version](https://github.com/ACCLAB/DABEST-Matlab) of DABEST.
